@@ -5,6 +5,11 @@ print.pcpscurve<-function(x, ...){
 	res <- summary.pcpscurve(x)
 	cat("Call:\n")
 	cat(deparse(x$call), "\n\n")
+	if(length(x$list.warning)>0){
+	  cat("List of warning:\n")
+	  namestemp <- SYNCSA::CollectNames(x$list.warning, prefix = "$list.warning$")
+	  cat(unlist(namestemp, use.names = FALSE), sep = "\n")
+	}
 	cat("PCPS curve observed:\n")
 	print(res$curve.obs)
 	if(!is.null(x$curve.null.ts)){
